@@ -1,4 +1,5 @@
-#[derive(Clone, Copy)]
+use serde::{Deserialize, Serialize};
+#[derive(Clone, Copy, Serialize, Deserialize)]
 pub enum LogLevel {
     Off,
     Error,
